# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:quota, :parent => Puppet::Parameter::ZfsProperty) do
  include EasyType

  desc <<-DESC
    Specifies the quota on the disk or share.

        zfs_...{
          ...
          quota => '1G'
          ...
        }
  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  munge do |size|
    return size if size.to_s == 'absent'
    return size if size.is_a?(Numeric)

    real_size = case size
                when /^\d*\.?\d+(K|k)$/
                  @unit = 1024
                  size.chop.to_f * @unit
                when /^\d*\.?\d+(M|m)$/
                  @unit = 1024 * 1024
                  size.chop.to_f * @unit
                when /^\d*\.?\d+(G|g)$/
                  @unit = 1024 * 1024 * 1024
                  size.chop.to_f * @unit
                when /^\d*\.?\d+(T|t)$/
                  @unit = 1024 * 1024 * 1024 * 1024
                  size.chop.to_f * @unit
                when /^\d*\.?\d+$/
                  @unit = 1
                  size.to_f
                else
                  fail("Quota #{size} is an invalid size")
                end
    # rubocop:disable Lint/FloatComparison
    fail "Quota is #{real_size}, but needs to be greater then 133415.0" if (real_size < 133_415.0) && (real_size != 0.0)
    # rubocop:enable Lint/FloatComparison

    real_size
  end
  # rubocop:disable Naming/MethodParameterName
  def insync?(is)
    # rubocop:enable Naming/MethodParameterName
    (is / @unit).round(2) == (should / @unit).round(2)
  end
end
