# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop:disable Style/Documentation
module Puppet_X
  module EnterpriseModules
    class RestfullPath
      # rubocop:enable Style/Documentation
      VARIABLE_REGEXP = /%\{(.*)\}/.freeze

      def initialize(path)
        @path = path
      end

      def contains_variables?
        !@path.scan(VARIABLE_REGEXP).empty?
      end

      def unassigned(path)
        result = []
        current_segments = path.split('/') - ['']
        segments.each_with_index do |segment, i|
          variable_name = segment.scan(VARIABLE_REGEXP).flatten.first
          current_value = current_segments[i]
          result << variable_name.to_sym if variable_name && !current_value
        end
        result
      end

      def variables(path)
        result = {}
        current_segments = path.split('/') - ['']
        segments.each_with_index do |segment, i|
          variable_name = segment.scan(VARIABLE_REGEXP).flatten.first
          current_value = current_segments[i]
          result[variable_name.to_sym] = current_value if variable_name && current_value
        end
        result
      end

      def subst(hash)
        filled_in_segments = []
        segments.each do |segment|
          # rubocop:disable Style/RedundantBegin
          begin
            # rubocop:enable Style/RedundantBegin
            substituted_value = segment % hash
            #
            # When String % is called with a non-existing key_name
            # in the Hash, it should throw an error. Don't know why,
            # but sometimes this doesn't happen. To make sure it still works
            # we do an extra check
            #
            break if substituted_value =~ VARIABLE_REGEXP

            filled_in_segments << substituted_value
          rescue KeyError
            break
          end
        end
        "/#{filled_in_segments.join('/')}"
      end

      def segments
        @path.split('/') - ['']
      end

      def ==(other)
        @path == other
      end

      def to_s
        @path
      end
    end
  end
end
