# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
# rubocop:disable Style/Documentation
module Puppet_X
  module EnterpriseModules
    module Settings
      # rubocop:enable Style/Documentation
      def self.included(parent)
        parent.extend(Settings)
      end

      def setting_for(key)
        settings[key]
      end

      def configuration
        @configuration ||= read_from_yaml
      end

      def settings
        configuration[environment]
      end

      def read_from_yaml
        if File.exist?(settings_file)
          # rubocop:disable Security/Open
          open(settings_file) { |f| YAML.safe_load(f) }
          # rubocop:enable Security/Open
        else
          { 'default' => {} }
        end
      end

      def settings_file
        Pathname.new(SETTINGS_FILE).expand_path
      end
    end
  end
end
